@@ -3,7 +3,7 @@
 #define CPL_LIBRARY_H
 
 /* For the header, either the CPL one can be used, or the header that was
-   extracted from the 6.1.1 release. For API safety, it is better to include
+   extracted from the 6.3 release. For API safety, it is better to include
    the one provided with python-cpl. The other option is just for the adoption
    to a new CPL version.
    */
@@ -13,11 +13,11 @@
 #include "cpl_api.h"
 #endif
 
-#if CPL_VERSION_CODE < CPL_VERSION(6,0,0)
-#error CPL version too old. Minimum required version is 6.0.0.
+#if CPL_VERSION_CODE < CPL_VERSION(6,3,0)
+#error CPL version too old. Minimum required version is 6.3.0.
 #endif
-#if CPL_VERSION_CODE > CPL_VERSION(6,2,0)
-#warning Newer CPL version: check API compability with 6.2.0 at http://upstream-tracker.org/versions/cpl.html
+#if CPL_VERSION_CODE > CPL_VERSION(6,3,0)
+#warning Newer CPL version: check API compability with 6.3.0 at http://upstream-tracker.org/versions/cpl.html
 #endif
 
 extern unsigned long supported_versions[];
@@ -68,7 +68,7 @@ typedef struct {
     typeof(cpl_frame_set_filename) *frame_set_filename;
     typeof(cpl_frame_set_tag) *frame_set_tag;
     typeof(cpl_frameset_delete) *frameset_delete;
-    typeof(cpl_frameset_get_frame) *frameset_get_frame;
+    typeof(cpl_frameset_get_position) *frameset_get_position;
     typeof(cpl_frameset_get_size) *frameset_get_size;
     typeof(cpl_frameset_insert) *frameset_insert;
     typeof(cpl_frameset_new) *frameset_new;
