@@ -134,7 +134,7 @@ class ProcessingInfo(object):
                 self.md5sums[self.calib[cat]] = md5
         raw = _get_rec_keys(header, 'RAW', 'CATG', 'NAME', datapaths)
         if raw:
-            self.tag = raw.keys()[0]
+            self.tag = list(raw.keys())[0]
             self.raw = raw[self.tag]
             md5 = _get_rec_keys(header, 'RAW', 'CATG', 'DATAMD5')[self.tag]
             if isinstance(md5, list):
@@ -166,41 +166,41 @@ class ProcessingInfo(object):
                          (self.pipeline, self.name, self.version[1], 
                           self.cpl_version))
         scriptfile.write('%s = cpl.Recipe(%s, version = %s)\n' % 
-                         (self.name, `self.name`, `self.version[0]`))
+                         (self.name, repr(self.name), repr(self.version[0])))
         scriptfile.write('\n# Parameters:\n')
         for k,v in self.param.items():
-            scriptfile.write('%s.param.%s = %s\n' % (self.name, k, `v`))
+            scriptfile.write('%s.param.%s = %s\n' % (self.name, k, repr(v)))
         if self.calib:
             scriptfile.write('\n# Calibration frames:\n')
         for k,v in self.calib.items():
-            scriptfile.write('%s.calib.%s = %s\n' % (self.name, k, `v`))
+            scriptfile.write('%s.calib.%s = %s\n' % (self.name, k, repr(v)))
         scriptfile.write('\n# Process input frames:\n')
-        scriptfile.write('%s.tag = %s\n' % (self.name, `self.tag`))
-        scriptfile.write('res = %s(%s)\n' % (self.name, `self.raw`))
+        scriptfile.write('%s.tag = %s\n' % (self.name, repr(self.tag)))
+        scriptfile.write('res = %s(%s)\n' % (self.name, repr(self.raw)))
         scriptfile.write('%s = res.%s\n' % (self.product.lower(), self.product))
         scriptfile.write('%s.writeto(%s)\n' % (self.product.lower(), 
-                                               `self.orig_filename`))
+                                               repr(self.orig_filename)))
 
     def printinfo(self):
-        print 'Recipe: %s, Version %s, CPL version %s ' % (
-            self.name, self.version, self.cpl_version)
-        print 'Parameters:'
+        print('Recipe: %s, Version %s, CPL version %s ' % (
+                self.name, self.version, self.cpl_version))
+        print('Parameters:')
         for k,v in self.param.items():
-            print ' %s.%s.%s = %s' % (self.pipeline, self.name, k, v)
+            print(' %s.%s.%s = %s' % (self.pipeline, self.name, k, v))
         if self.calib:
-            print 'Calibration frames:'
+            print('Calibration frames:')
         for k,v in self.calib.items():
             if isinstance(v, str):
-                print ' %s %s' % (v,k)
+                print(' %s %s' % (v,k))
             else:
                 for n in v:
-                    print ' %s %s' % (n,k)
-        print 'Input frames:'
+                    print(' %s %s' % (n,k))
+        print('Input frames:')
         if isinstance(self.raw, str):
-            print ' %s %s' % (self.raw, self.tag)
+            print(' %s %s' % (self.raw, self.tag))
         else:
             for n in self.raw:
-                print ' %s %s' % (n, self.tag)
+                print(' %s %s' % (n, self.tag))
 
 def _get_rec_keys(header, key, name, value, datapaths = None):
     '''Get a dictionary of key/value pairs from the DFS section of the
@@ -277,7 +277,7 @@ if __name__ == '__main__':
         'WAVECAL_TABLE':'result', 'PIXTABLE_OBJECT':'result', 
         }
     for arg in sys.argv[1:]:
-        print '---------------------' 
-        print 'file: %s' % arg
+        print('---------------------')
+        print('file: %s' % arg)
         pi = ProcessingInfo(arg, datapaths = datapaths)
         pi.printinfo()
