@@ -22,7 +22,7 @@ def load_sof(source):
     
       import cpl
       myrecipe = cpl.Recipe('muse_bias')
-      myrecipe.calib = cpl.esorex.read_sof(file('muse_bias.sof'))
+      myrecipe.calib = cpl.esorex.read_sof(open('muse_bias.sof'))
     
     .. note::
 
@@ -34,8 +34,8 @@ def load_sof(source):
 
     '''
     if isinstance(source, str):
-        return load_sof(file(source) if os.path.exists(source) else source.split('\n'))
-    elif isinstance(source, (file, list)):
+        return load_sof(open(source) if os.path.exists(source) else source.split('\n'))
+    else:
         res = dict()
         for line in source:
             if not line or line.startswith('#'):
@@ -50,9 +50,6 @@ def load_sof(source):
             else:
                 res[key] = [ res[key], fn ]
         return res
-    else:
-        raise ValueError('Cannot assign type %s to framelist' % 
-                         source.__class__.__name__)
 
 def load_rc(source = None):
     '''Read an :program:`EsoRex` configuration file.
@@ -75,10 +72,10 @@ def load_rc(source = None):
 
     '''
     if source is None:
-        source = file(os.path.expanduser('~/.esorex/esorex.rc'))
+        source = open(os.path.expanduser('~/.esorex/esorex.rc'))
     if isinstance(source, str):
-        return load_rc(file(source) if os.path.exists(source) else source.split('\n'))
-    elif isinstance(source, (file, list)):
+        return load_rc(open(source) if os.path.exists(source) else source.split('\n'))
+    else:
         res = dict()
         for line in source:
             if not line or not line.strip() or line.startswith('#'):
@@ -88,9 +85,6 @@ def load_rc(source = None):
             if name and value:
                 res[name.strip()] = value.strip()
         return res
-    else:
-        raise ValueError('Cannot assign type %s to parameter list' % 
-                         source.__class__.__name__)
 
 def init(source = None):
     '''Set up the logging and the recipe search path from the
@@ -102,15 +96,15 @@ def init(source = None):
     '''
 
     rc = cpl.esorex.load_rc(source)
-    if rc.has_key('esorex.caller.recipe-dir'):
+    if 'esorex.caller.recipe-dir' in rc:
         cpl.Recipe.path = rc['esorex.caller.recipe-dir'].split(':')
-    if rc.has_key('esorex.caller.msg-level'):
+    if 'esorex.caller.msg-level' in rc:
         msg.level = rc['esorex.caller.msg-level']
-    if rc.has_key('esorex.caller.log-level'):
+    if 'esorex.caller.log-level' in rc:
         log.level = rc['esorex.caller.log-level']
-    if rc.has_key('esorex.caller.log-dir'):
+    if 'esorex.caller.log-dir' in rc:
         log.dir = rc['esorex.caller.log-dir']
-    if rc.has_key('esorex.caller.log-file'):
+    if 'esorex.caller.log-file' in rc:
         log.filename = rc['esorex.caller.log-file']
 
 class CplLogger(object):
@@ -145,12 +139,14 @@ class CplLogger(object):
                 self.handler = None
             if self.handler:
                 logging.getLogger().addHandler(self.handler)
+                self.handler.setLevel(self._level)
                 self.handler.setFormatter(logging.Formatter(self.format,
                                                             '%H:%M:%S'))
 
     def _shutdown_handler(self):
         if self.handler:
             logging.getLogger().removeHandler(self.handler)
+            self.handler.close()
             self.handler = None
 
     @property
@@ -162,7 +158,7 @@ class CplLogger(object):
 
     @level.setter
     def level(self, level):
-        if isinstance(level, (str, unicode)):
+        if isinstance(level, (str)):
             level = cpl.logger.level[level.upper()]
         if level == CplLogger.OFF:
             self._shutdown_handler()
@@ -243,7 +239,7 @@ class CplLogger(object):
             self._init_handler()
 
     def __repr__(self):
-        return 'cpl.esorex.CplLogger(msg=%s)' % `self._msg`
+        return 'cpl.esorex.CplLogger(msg=%s)' % repr(self._msg)
 
 msg = CplLogger(msg = True)
 '''This variable is a :class:`CplLogger` instance that provides a convienience
