@@ -1,8 +1,9 @@
+from __future__ import absolute_import
 import os
 import tempfile
 import pyfits
 
-import md5sum
+from . import md5sum
 
 class FrameConfig(object):
     '''Frame configuration. 
@@ -60,10 +61,12 @@ class FrameConfig(object):
         return str(self.frames)
 
     def __repr__(self):
-        return 'FrameDef(%s, frames=%s)' % (`self.tag`, `self.frames`)
+        return 'FrameDef(%s, frames=%s)' % (repr(self.tag), repr(self.frames))
 
     def _doc(self):
-        if self.max == 1:
+        if self.max is None or self.min is None:
+            r = ' one frame or list of frames'
+        elif self.max == 1:
             r = ' one frame'
         elif self.min > 1 and self.max > self.min:
             r = ' list of %i-%i frames' % (self.min, self.max)
@@ -88,7 +91,7 @@ class FrameList(object):
         if isinstance(other, self.__class__):
             self._set_items((o.tag, o.frames) for o in other)
         elif isinstance(other, dict):
-            self._set_items(other.iteritems())
+            self._set_items(other.items())
         elif other:
             self._set_items(other)
 
@@ -120,7 +123,7 @@ class FrameList(object):
         return self._cpl_dict or self._values
 
     def __iter__(self):
-        return self._dict.itervalues()
+        return iter(self._dict.values())
 
     def __getitem__(self, key):
         return self._dict[key]
@@ -157,7 +160,10 @@ class FrameList(object):
         return self._dict.keys()
 
     def __repr__(self):
-        return `list(self)`
+        return repr(dict(self))
+
+    def __str__(self):
+        return str(dict(self))
 
     def __eq__(self, other):
         return dict(self) == other
