@@ -1,16 +1,18 @@
+from __future__ import absolute_import
 import os
 import shutil
 import tempfile
 import threading
 import collections
+import warnings
 
 import pyfits
-import CPL_recipe
-import esorex
-from frames import FrameList, mkabspath, expandframelist
-from result import Result, RecipeCrash
-from param import ParameterList
-from logger import LogServer
+from . import CPL_recipe
+from . import esorex
+from cpl.frames import FrameList, mkabspath, expandframelist
+from cpl.result import Result, RecipeCrash
+from cpl.param import ParameterList
+from cpl.logger import LogServer
 
 class Recipe(object):
     '''Pluggable Data Reduction Module (PDRM) from a ESO pipeline. 
@@ -67,8 +69,8 @@ class Recipe(object):
         if not filename:
             filename = Recipe.get_recipefilename(name, version)
             if not filename:
-                raise IOError('Recipe %s not found at path %s' 
-                              % (`name`, `Recipe.path`))
+                raise IOError('Recipe %s not found at path %s'
+                              % (repr(name), repr(Recipe.path)))
         self.__file__ = filename
         '''Shared library file name.'''
 
@@ -77,8 +79,8 @@ class Recipe(object):
             raise IOError('wrong version %s (requested %s) for %s in %s' %
                           (str(self.version), str(version), name, filename))
         if not self._recipe.cpl_is_supported():
-            warn("Unsupported CPL version %s linked to %s" %
-                 self._recipe.version()[1], filename)
+            warnings.warn("Unsupported CPL version %s linked to %s" %
+                          (self.cpl_version, filename))
         self._param = ParameterList(self)
         self._calib = FrameList(self)
 
@@ -178,7 +180,7 @@ class Recipe(object):
         if self.tags is None or t in self.tags:
             self._tag = t 
         else:
-            raise KeyError("Tag %s not in %s" % (`t`, str(self.tags)))
+            raise KeyError("Tag %s not in %s" % (repr(t), str(self.tags)))
 
     @property
     def calib(self):
@@ -211,9 +213,9 @@ class Recipe(object):
         Using :class:`pyfits.HDUList` is useful when it needs to be patched
         before fed into the recipe. 
 
-        >>> master_bias = pyfits.open('master_bias_0.fits')
+        >>> master_bias = pyfits.open('MASTER_BIAS_0.fits')
         >>> master_bias[0].header['HIERARCH ESO DET CHIP1 OUT1 GAIN'] = 2.5
-        >>> muse_scibasic.calib.MASTER_BIAS = 'master_bias_0.fits'
+        >>> muse_scibasic.calib.MASTER_BIAS = master_bias
 
         Note that :class:`pyfits.HDUList` objects are stored in temporary
         files before the recipe is called which may produce some
@@ -245,7 +247,7 @@ class Recipe(object):
 
     @calib.setter
     def calib(self, source = None):
-        if isinstance(source, (str, file)):
+        if isinstance(source, str) or hasattr(source, 'read'):
             source = esorex.load_sof(source)
         self._calib = FrameList(self, source) 
 
@@ -310,7 +312,7 @@ class Recipe(object):
 
     @param.setter
     def param(self, source = None):
-        if isinstance(source, (str, file)):
+        if isinstance(source, str) or hasattr(source, 'read'):
             source = esorex.load_rc(source)
         self._param = ParameterList(self, source)
 
@@ -418,7 +420,7 @@ class Recipe(object):
         try:
             return Result(self._recipe.frameConfig(), output_dir,
                           self._recipe.run(output_dir, parlist, framelist,
-                                           runenv.items(), 
+                                           list(runenv.items()), 
                                            logger.logfile, logger.level,
                                            self.memory_dump),
                           input_len, logger, output_format)
@@ -448,13 +450,13 @@ class Recipe(object):
                 m[tag].append(f)
             else:
                 m[tag] = [ m[tag], f ]
-        return list(m.iteritems())
+        return list(m.items())
 
     def _cleanup(self, output_dir, logger, delete):
         try:
             bt = os.path.join(output_dir, 'recipe.backtrace-unprocessed')
             if os.path.exists(bt):
-                with file(bt) as bt_file:
+                with open(bt) as bt_file:
                     os.rename(bt, os.path.join(output_dir, 'recipe.backtrace'))
                     ex = RecipeCrash(bt_file)
                     ex.log(logger.logger)
@@ -467,27 +469,31 @@ class Recipe(object):
     def _doc(self):
         s = '%s\n\n%s\n\n' % (self.description[0], self.description[1])
         
-        r = 'Parameters:\n' 
-        maxlen = max(len(p.name) for p in self.param)
-        for p in self.param:
-            r += ' %s: %s (default: %s)\n' % (
-                p.name.rjust(maxlen), p.__doc__, `p.default`)
-        r += '\n'
+        if len(self.param) > 0:
+            r = 'Parameters:\n'
+            maxlen = max(len(p.name) for p in self.param)
+            for p in self.param:
+                r += ' %s: %s (default: %s)\n' % (
+                    p.name.rjust(maxlen), p.__doc__, repr(p.default))
+            r += '\n'
+        else:
+            r = 'No parameters\n'
         if self._recipe.frameConfig() is not None:
-            c = 'Calibration frames: %s\n\n' % `[f.tag for f in self.calib]`
+            c = 'Calibration frames: %s\n\n' % repr([f.tag for f in self.calib])
         else:
             c = ''
         if self.tags is not None:
             t = 'Raw and product frames:\n'
             maxlen = max(len(f) for f in self.tags)
             for f in self.tags:
-                t += ' %s --> %s\n' % (f.rjust(maxlen), `self.output[f]`)
+                t += ' %s --> %s\n' % (f.rjust(maxlen), repr(self.output[f]))
         else:
             t = ''
         return s + r + c + t + '\n\n'
 
     def __repr__(self):
-        return 'Recipe(%s, version = %s)' % (`self.__name__`, `self.version[0]`)
+        return 'Recipe(%s, version = %s)' % (repr(self.__name__), 
+                                             repr(self.version[0]))
 
     @staticmethod
     def list():
@@ -516,8 +522,8 @@ class Recipe(object):
                         continue
                     if version in p[1:3]:
                         return f
-                    if rversion < p[2]:
-                        rversion = p[2]
+                    if rversion < p[1]:
+                        rversion = p[1]
                         filename = f
         return filename
 
@@ -577,13 +583,29 @@ class Threaded(threading.Thread):
             except Exception as exception:
                 self._exception = exception
 
-    def __getattr__(self, name):
+    @property
+    def _result(self):
         self.join()
         if self._exception is None:
-            return self._res.__dict__[name]
+            return self._res
         else:
             raise self._exception
 
+    def __getitem__(self, key):
+        return self._result[key]
+
+    def __contains__(self, key):
+        return key in self._result.tags
+
+    def __len__(self):
+        return len(self._result.tags)
+
+    def __iter__(self):
+        return self._result.__iter__()
+
+    def __getattr__(self, name):
+        return self._result.__dict__[name]
+
     @staticmethod
     def set_maxthreads(n):
         with Threaded.pool_sema:
